#
# Conditional build:
%bcond_without	doc	# API documentation
%bcond_without	tests	# unit tests
%bcond_without	python2 # CPython 2.x module
%bcond_with	python3 # CPython 3.x module (built from python3-ZODB.spec)

%define		module		ZODB
Summary:	Python object-oriented database
Summary(pl.UTF-8):	Pythonowa zorientowana obietowo baza danych
Name:		python-%{module}
# keep 5.x here for python2 support
Version:	5.8.1
Release:	1
License:	ZPL v2.1
Group:		Libraries/Python
#Source0Download: https://pypi.org/simple/zodb/
Source0:	https://files.pythonhosted.org/packages/source/Z/ZODB/%{module}-%{version}.tar.gz
# Source0-md5:	3d95891e2993d81d4d5b0358c5ce72cb
URL:		https://zodb.org/
BuildRequires:	rpm-pythonprov
BuildRequires:	rpmbuild(macros) >= 1.714
%if %{with python2}
BuildRequires:	python-modules >= 1:2.7
BuildRequires:	python-setuptools
%if %{with tests}
BuildRequires:	python-BTrees >= 4.2.0
BuildRequires:	python-ZConfig
BuildRequires:	python-manuel
BuildRequires:	python-mock
BuildRequires:	python-persistent >= 4.4.0
BuildRequires:	python-six
BuildRequires:	python-transaction > 2.4
BuildRequires:	python-zc.lockfile
BuildRequires:	python-zodbpickle >= 1.0.1
BuildRequires:	python-zope.interface
BuildRequires:	python-zope.testing
BuildRequires:	python-zope.testrunner >= 4.4.6
%endif
%endif
%if %{with python3}
BuildRequires:	python3-modules >= 1:3.5
BuildRequires:	python3-setuptools
%if %{with tests}
BuildRequires:	python3-BTrees >= 4.2.0
BuildRequires:	python3-ZConfig
BuildRequires:	python3-manuel
BuildRequires:	python3-persistent >= 4.4.0
BuildRequires:	python3-six
BuildRequires:	python3-transaction >= 2.4
BuildRequires:	python3-zc.lockfile
BuildRequires:	python3-zodbpickle >= 1.0.1
BuildRequires:	python3-zope.interface
BuildRequires:	python3-zope.testing
BuildRequires:	python3-zope.testrunner >= 4.4.6
%endif
%endif
%if %{with doc}
BuildRequires:	python-j1m.sphinxautozconfig
BuildRequires:	python-sphinx_rtd_theme
BuildRequires:	python-sphinxcontrib-zopeext
BuildRequires:	sphinx-pdg-2
%endif
Requires:	python-modules >= 1:2.7
BuildArch:	noarch
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
ZODB provides an object-oriented database for Python that provides a
high-degree of transparency.

- no separate language for database operations
- very little impact on your code to make objects persistent
- no database mapper that partially hides the database.
- almost no seam between code and database.

ZODB is an ACID Transactional database.

%description -l pl.UTF-8
ZODB dostarcza obiektowo zorientowaną bazę danych dla Pythona,
zapewniającą duży stopień przezroczystości.

- brak osobnego języka dla operacji bazodanowych
- bardzo mały wpływ na kod, aby obiekty były trwałe
- brak odwzorowań bazy danych ukrywających częściowo bazę
- prawie bez dodatkowych spojeń między kodem a bazą danych

ZODB to transakcyjna baza danych ACID.

%package -n python3-%{module}
Summary:	Python object-oriented database
Summary(pl.UTF-8):	Pythonowa zorientowana obietowo baza danych
Group:		Documentation
Requires:	python3-modules >= 1:3.5

%description -n python3-%{module}
ZODB provides an object-oriented database for Python that provides a
high-degree of transparency.

- no separate language for database operations
- very little impact on your code to make objects persistent
- no database mapper that partially hides the database.
- almost no seam between code and database.

ZODB is an ACID Transactional database.

%description -n python3-%{module} -l pl.UTF-8
ZODB dostarcza obiektowo zorientowaną bazę danych dla Pythona,
zapewniającą duży stopień przezroczystości.

- brak osobnego języka dla operacji bazodanowych
- bardzo mały wpływ na kod, aby obiekty były trwałe
- brak odwzorowań bazy danych ukrywających częściowo bazę
- prawie bez dodatkowych spojeń między kodem a bazą danych

ZODB to transakcyjna baza danych ACID.

%package apidocs
Summary:	API documentation for Python %{module} module
Summary(pl.UTF-8):	Dokumentacja API modułu Pythona %{module}
Group:		Documentation

%description apidocs
API documentation for Python %{module} module.

%description apidocs -l pl.UTF-8
Dokumentacja API modułu Pythona %{module}.

%prep
%setup -q -n %{module}-%{version}

%build
%if %{with python2}
%py_build

%if %{with tests}
PYTHONPATH=$(pwd)/src \
zope-testrunner-2 --test-path=src -a 1000 -v
%endif
%endif

%if %{with python3}
%py3_build

%if %{with tests}
PYTHONPATH=$(pwd)/src \
zope-testrunner-3 --test-path=src -a 1000 -v
%endif
%endif

%if %{with doc}
PYTHONPATH=$(pwd)/src \
%{__make} -C docs html \
	SPHINXBUILD=sphinx-build-2
%endif

%install
rm -rf $RPM_BUILD_ROOT

%if %{with python2}
%py_install

%py_postclean

for f in fsdump fsoids fsrefs fstail repozo ; do
%{__mv} $RPM_BUILD_ROOT%{_bindir}/$f $RPM_BUILD_ROOT%{_bindir}/${f}-2
done
%endif

%if %{with python3}
%py3_install

for f in fsdump fsoids fsrefs fstail repozo ; do
%{__mv} $RPM_BUILD_ROOT%{_bindir}/$f $RPM_BUILD_ROOT%{_bindir}/${f}-3
ln -sf ${f}-3 $RPM_BUILD_ROOT%{_bindir}/$f
done
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%if %{with python2}
%files
%defattr(644,root,root,755)
%doc CHANGES.rst COPYRIGHT.txt HISTORY.rst README.rst
%attr(755,root,root) %{_bindir}/fsdump-2
%attr(755,root,root) %{_bindir}/fsoids-2
%attr(755,root,root) %{_bindir}/fsrefs-2
%attr(755,root,root) %{_bindir}/fstail-2
%attr(755,root,root) %{_bindir}/repozo-2
%{py_sitescriptdir}/%{module}
%{py_sitescriptdir}/ZODB-%{version}-py*.egg-info
%endif

%if %{with python3}
%files -n python3-%{module}
%defattr(644,root,root,755)
%doc CHANGES.rst COPYRIGHT.txt HISTORY.rst README.rst
%attr(755,root,root) %{_bindir}/fsdump-3
%attr(755,root,root) %{_bindir}/fsoids-3
%attr(755,root,root) %{_bindir}/fsrefs-3
%attr(755,root,root) %{_bindir}/fstail-3
%attr(755,root,root) %{_bindir}/repozo-3
%attr(755,root,root) %{_bindir}/fsdump
%attr(755,root,root) %{_bindir}/fsoids
%attr(755,root,root) %{_bindir}/fsrefs
%attr(755,root,root) %{_bindir}/fstail
%attr(755,root,root) %{_bindir}/repozo
%{py3_sitescriptdir}/%{module}
%{py3_sitescriptdir}/ZODB-%{version}-py*.egg-info
%endif

%if %{with doc}
%files apidocs
%defattr(644,root,root,755)
%doc docs/build/html/{_downloads,_images,_modules,_static,articles,guide,reference,*.html,*.js}
%endif
%changelog
* Sun May 18 2025 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/python-ZODB.git;a=log;h=master

* Sun May 18 2025 Jakub Bogusz <qboosh@pld-linux.org> 13fbb3c
- disable python3 here

* Sun May 18 2025 Jakub Bogusz <qboosh@pld-linux.org> f872840
- updated to 5.8.1, finished packaging

* Tue Mar 11 2025 Jan Rękorajski <baggins@pld-linux.org> c4d1d84
- doc/test rebuild for python 3.13

* Mon Mar 10 2025 Jan Rękorajski <baggins@pld-linux.org> 90f6d19
- python 3.13 rebuild

* Wed Mar 30 2022 Jan Rękorajski <baggins@pld-linux.org> 896a0b6
- rebuild with tests and docs

* Sat Mar 26 2022 Jan Rękorajski <baggins@pld-linux.org> b950ac1
- rebuild with python 3.10

* Fri Mar 25 2022 Jan Rękorajski <baggins@pld-linux.org> 715c7f4
- rebuild with python 3.10

* Sat Mar 06 2021 Jan Palus <atler@pld-linux.org> d6e63dd
- release 5 (by relup.sh)

* Sat Feb 27 2021 Jan Rękorajski <baggins@pld-linux.org> b8e491f
- release 4 (by relup.sh)

* Mon Oct 28 2019 Jan Rękorajski <baggins@pld-linux.org> 8f0b16f
- rebuild with python 3.8
- release 3 (by relup.sh)

* Sun Jul 01 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> cb39a9e
- python 3.7 rebuild
- release 2 (by relup.sh)

* Tue Nov 14 2017 Mateusz Korniak <matkor@pld-linux.org> 5057eec
- Rel 1. Works for me.

* Mon Nov 13 2017 Mateusz Korniak <matkor@pld-linux.org> 5f1a059
- Initial 5.3.0.

